@@ -4,6 +4,8 @@
 #include "esphome/components/sensor/sensor.h"
 #include "esp_one_wire.h"
 
+#include <vector>
+
 namespace esphome {
 namespace dallas {
 
@@ -11,8 +13,7 @@ class DallasTemperatureSensor;
 
 class DallasComponent : public PollingComponent {
  public:
-  explicit DallasComponent(ESPOneWire *one_wire);
-
+  void set_pin(InternalGPIOPin *pin) { pin_ = pin; }
   void register_sensor(DallasTemperatureSensor *sensor);
 
   void setup() override;
@@ -24,6 +25,7 @@ class DallasComponent : public PollingComponent {
  protected:
   friend DallasTemperatureSensor;
 
+  InternalGPIOPin *pin_;
   ESPOneWire *one_wire_;
   std::vector<DallasTemperatureSensor *> sensors_;
   std::vector<uint64_t> found_sensors_;
